package net.sf.jsptest.assertion;

import org.w3c.dom.Element;

public class LinkAssertion extends DOMAssertion {

    public LinkAssertion(Element context) {
        this.context = context;
    }

    public void withText(String labelText) {
        shouldContainElement("Link with text '" + labelText
                + "' was not found from " + getContextAsString(),
                "//A[text()='" + labelText + "']");
    }

    public void withPartialText(String substringOfLabelText) {
        shouldContainElement("Link with partial text '"
                + substringOfLabelText + "' was not found from "
                + getContextAsString(), "//A[fn:contains(text(), '"
                + substringOfLabelText + "')]");
    }

    public void withName(String name) {
        shouldContainElement("Link with name '" + name
                + "' was not found from " + getContextAsString(),
                "//A[@NAME='" + name + "']");
    }

    public void withId(String id) {
        shouldContainElement("Link with ID '" + id
                + "' was not found from " + getContextAsString(),
                "//A[@ID='" + id + "']");
    }

    public void withHref(String url) {
        shouldContainElement("Link pointing to " + url
                + " was not found from " + getContextAsString(),
                "//A[@HREF='" + url + "']");
    }

    public void withClass(String cssClass) {
        shouldContainElement("Link with CSS class '" + cssClass
                + "' was not found from " + getContextAsString(),
                "//A[@CLASS='" + cssClass + "']");
    }

    public void withImageId(String id) {
        shouldContainElement("Image link with image ID '" + id
                + "' was not found from " + getContextAsString(),
                "//A/IMG[@ID='" + id + "']");
    }

    public void withImageTitle(String title) {
        shouldContainElement("Image link with image titled '" + title
                + "' was not found from " + getContextAsString(),
                "//A/IMG[@TITLE='" + title + "']");
    }

    public void withImageName(String name) {
        shouldContainElement("Image link with image named '" + name
                + "' was not found from " + getContextAsString(),
                "//A/IMG[@NAME='" + name + "']");
    }

    public void withImageSrc(String url) {
        shouldContainElement("Image link with image URL '" + url
                + "' was not found from " + getContextAsString(),
                "//A/IMG[@SRC='" + url + "']");
    }

    public void withImageFileName(String filename) {
        shouldContainElement(
                "Image link with the image URL ending with '"
                        + filename + "' was not found from "
                        + getContextAsString(),
                "//A/IMG[fn:ends-with(@SRC, '" + filename + "')]");
    }
}
